import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/modern';
import { useFocus } from '@alfalab/hooks';
import { CheckIcon } from './icon.js';

const defaultColors = {"box":"checkbox__box_4q38e","checkedIcon":"checkbox__checkedIcon_4q38e","component":"checkbox__component_4q38e","disabled":"checkbox__disabled_4q38e","checked":"checkbox__checked_4q38e","indeterminate":"checkbox__indeterminate_4q38e","indeterminateLine":"checkbox__indeterminateLine_4q38e","label":"checkbox__label_4q38e","hint":"checkbox__hint_4q38e"};
require('./styles/default.css')

const styles = {"component":"checkbox__component_4gz7f","start":"checkbox__start_4gz7f","center":"checkbox__center_4gz7f","addons":"checkbox__addons_4gz7f","block":"checkbox__block_4gz7f","box":"checkbox__box_4gz7f","checkedIcon":"checkbox__checkedIcon_4gz7f","size-20":"checkbox__size-20_4gz7f","disabled":"checkbox__disabled_4gz7f","focused":"checkbox__focused_4gz7f","content":"checkbox__content_4gz7f","label":"checkbox__label_4gz7f","errorMessage":"checkbox__errorMessage_4gz7f","hint":"checkbox__hint_4gz7f","indeterminateLine":"checkbox__indeterminateLine_4gz7f"};
require('./styles/index.css')

const invertedColors = {"box":"checkbox__box_19bk9","checkedIcon":"checkbox__checkedIcon_19bk9","component":"checkbox__component_19bk9","disabled":"checkbox__disabled_19bk9","checked":"checkbox__checked_19bk9","indeterminate":"checkbox__indeterminate_19bk9","indeterminateLine":"checkbox__indeterminateLine_19bk9","label":"checkbox__label_19bk9","hint":"checkbox__hint_19bk9"};
require('./styles/inverted.css')

const colorStyles = {
    default: defaultColors,
    inverted: invertedColors,
};
const SIZE_TO_CLASSNAME_MAP = {
    s: 'size-20',
    m: 'size-24',
    20: 'size-20',
    24: 'size-24',
};
const Checkbox = forwardRef(({ checked, label, hint, size = 20, boxClassName, contentClassName, align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, hiddenInput = false, labelProps, error, inputRef, colors = 'default', ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    const colorStyle = colorStyles[colors];
    return (React.createElement("label", { ...labelProps, className: cn(styles.component, colorStyle.component, styles[SIZE_TO_CLASSNAME_MAP[size]], styles[align], className, labelProps?.className, {
            [styles.disabled]: disabled || inactive,
            [colorStyle.disabled]: disabled || inactive,
            [styles.checked]: checked,
            [colorStyle.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [colorStyle.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref, labelProps?.ref]) },
        !hiddenInput && (React.createElement("input", { type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ref: inputRef, ...restProps })),
        React.createElement("span", { className: cn(styles.box, colorStyle.box, boxClassName) },
            checked && (React.createElement(CheckIcon, { className: cn(styles.checkedIcon, colorStyle.checkedIcon) })),
            indeterminate && !checked && (React.createElement("span", { className: cn(styles.indeterminateLine, colorStyle.indeterminateLine) }))),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && (React.createElement("span", { className: cn(styles.label, colorStyle.label) }, label)),
            hint && !errorMessage && (React.createElement("span", { className: cn(styles.hint, colorStyle.hint) }, hint)),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};
Checkbox.displayName = 'Checkbox';

export { Checkbox };
