import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/moderncssm';
import { useFocus } from '@alfalab/hooks';
import { CheckIcon } from './icon.js';
import defaultColors from './styles/default.module.css';
import styles from './styles/index.module.css';
import invertedColors from './styles/inverted.module.css';

const colorStyles = {
    default: defaultColors,
    inverted: invertedColors,
};
const SIZE_TO_CLASSNAME_MAP = {
    s: 'size-20',
    m: 'size-24',
    20: 'size-20',
    24: 'size-24',
};
const Checkbox = forwardRef(({ checked, label, hint, size = 20, boxClassName, contentClassName, align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, hiddenInput = false, labelProps, error, inputRef, colors = 'default', ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    const colorStyle = colorStyles[colors];
    return (React.createElement("label", { ...labelProps, className: cn(styles.component, colorStyle.component, styles[SIZE_TO_CLASSNAME_MAP[size]], styles[align], className, labelProps?.className, {
            [styles.disabled]: disabled || inactive,
            [colorStyle.disabled]: disabled || inactive,
            [styles.checked]: checked,
            [colorStyle.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [colorStyle.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref, labelProps?.ref]) },
        !hiddenInput && (React.createElement("input", { type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ref: inputRef, ...restProps })),
        React.createElement("span", { className: cn(styles.box, colorStyle.box, boxClassName) },
            checked && (React.createElement(CheckIcon, { className: cn(styles.checkedIcon, colorStyle.checkedIcon) })),
            indeterminate && !checked && (React.createElement("span", { className: cn(styles.indeterminateLine, colorStyle.indeterminateLine) }))),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && (React.createElement("span", { className: cn(styles.label, colorStyle.label) }, label)),
            hint && !errorMessage && (React.createElement("span", { className: cn(styles.hint, colorStyle.hint) }, hint)),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};
Checkbox.displayName = 'Checkbox';

export { Checkbox };
